syntax = "proto3";

package protocols.grpc.rectify;

import "protocols/grpc/common/common.proto";

// Rectify Brick 相關訊息
message RectifyRequest {
  string text = 1;
  string client_id = 2;
  string session_id = 3;
  string request_id = 4;
  string source_language = 5;
}

message RectifyResponse {
  string corrected_text = 1;
  protocols.grpc.common.ErrorDetail error = 2;
}

// Rectify 服務
service RectifyService {
  rpc GetServiceInfo(protocols.grpc.common.ServiceInfoRequest) returns (protocols.grpc.common.ServiceInfoResponse);

  rpc Unary(RectifyRequest) returns (RectifyResponse);
}
