# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from llmbrick.protocols.grpc.common import common_pb2 as protocols_dot_grpc_dot_common_dot_common__pb2
from llmbrick.protocols.grpc.compose import compose_pb2 as protocols_dot_grpc_dot_compose_dot_compose__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in protocols/grpc/compose/compose_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ComposeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetServiceInfo = channel.unary_unary(
                '/protocols.grpc.compose.ComposeService/GetServiceInfo',
                request_serializer=protocols_dot_grpc_dot_common_dot_common__pb2.ServiceInfoRequest.SerializeToString,
                response_deserializer=protocols_dot_grpc_dot_common_dot_common__pb2.ServiceInfoResponse.FromString,
                _registered_method=True)
        self.Unary = channel.unary_unary(
                '/protocols.grpc.compose.ComposeService/Unary',
                request_serializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeRequest.SerializeToString,
                response_deserializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeResponse.FromString,
                _registered_method=True)
        self.OutputStreaming = channel.unary_stream(
                '/protocols.grpc.compose.ComposeService/OutputStreaming',
                request_serializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeRequest.SerializeToString,
                response_deserializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeResponse.FromString,
                _registered_method=True)


class ComposeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetServiceInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OutputStreaming(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ComposeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetServiceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceInfo,
                    request_deserializer=protocols_dot_grpc_dot_common_dot_common__pb2.ServiceInfoRequest.FromString,
                    response_serializer=protocols_dot_grpc_dot_common_dot_common__pb2.ServiceInfoResponse.SerializeToString,
            ),
            'Unary': grpc.unary_unary_rpc_method_handler(
                    servicer.Unary,
                    request_deserializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeRequest.FromString,
                    response_serializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeResponse.SerializeToString,
            ),
            'OutputStreaming': grpc.unary_stream_rpc_method_handler(
                    servicer.OutputStreaming,
                    request_deserializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeRequest.FromString,
                    response_serializer=protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocols.grpc.compose.ComposeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('protocols.grpc.compose.ComposeService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ComposeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetServiceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocols.grpc.compose.ComposeService/GetServiceInfo',
            protocols_dot_grpc_dot_common_dot_common__pb2.ServiceInfoRequest.SerializeToString,
            protocols_dot_grpc_dot_common_dot_common__pb2.ServiceInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Unary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/protocols.grpc.compose.ComposeService/Unary',
            protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeRequest.SerializeToString,
            protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OutputStreaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/protocols.grpc.compose.ComposeService/OutputStreaming',
            protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeRequest.SerializeToString,
            protocols_dot_grpc_dot_compose_dot_compose__pb2.ComposeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
