# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protocols/grpc/translate/translate.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'protocols/grpc/translate/translate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from llmbrick.protocols.grpc.common import common_pb2 as protocols_dot_grpc_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(protocols/grpc/translate/translate.proto\x12\x18protocols.grpc.translate\x1a\"protocols/grpc/common/common.proto\"\x9f\x01\n\x10TranslateRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x17\n\x0ftarget_language\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\x12\x12\n\nrequest_id\x18\x06 \x01(\t\x12\x17\n\x0fsource_language\x18\x07 \x01(\t\"\x8d\x01\n\x11TranslateResponse\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06tokens\x18\x02 \x03(\t\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x10\n\x08is_final\x18\x04 \x01(\x08\x12\x31\n\x05\x65rror\x18\x05 \x01(\x0b\x32\".protocols.grpc.common.ErrorDetail2\xcb\x02\n\x10TranslateService\x12g\n\x0eGetServiceInfo\x12).protocols.grpc.common.ServiceInfoRequest\x1a*.protocols.grpc.common.ServiceInfoResponse\x12`\n\x05Unary\x12*.protocols.grpc.translate.TranslateRequest\x1a+.protocols.grpc.translate.TranslateResponse\x12l\n\x0fOutputStreaming\x12*.protocols.grpc.translate.TranslateRequest\x1a+.protocols.grpc.translate.TranslateResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protocols.grpc.translate.translate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRANSLATEREQUEST']._serialized_start=107
  _globals['_TRANSLATEREQUEST']._serialized_end=266
  _globals['_TRANSLATERESPONSE']._serialized_start=269
  _globals['_TRANSLATERESPONSE']._serialized_end=410
  _globals['_TRANSLATESERVICE']._serialized_start=413
  _globals['_TRANSLATESERVICE']._serialized_end=744
# @@protoc_insertion_point(module_scope)
