# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protocols/grpc/intention/intention.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'protocols/grpc/intention/intention.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from llmbrick.protocols.grpc.common import common_pb2 as protocols_dot_grpc_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(protocols/grpc/intention/intention.proto\x12\x18protocols.grpc.intention\x1a\"protocols/grpc/common/common.proto\"t\n\x10IntentionRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x12\n\nrequest_id\x18\x04 \x01(\t\x12\x17\n\x0fsource_language\x18\x05 \x01(\t\">\n\x0fIntentionResult\x12\x17\n\x0fintent_category\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\"\x82\x01\n\x11IntentionResponse\x12:\n\x07results\x18\x01 \x03(\x0b\x32).protocols.grpc.intention.IntentionResult\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\".protocols.grpc.common.ErrorDetail2\xdd\x01\n\x10IntentionService\x12g\n\x0eGetServiceInfo\x12).protocols.grpc.common.ServiceInfoRequest\x1a*.protocols.grpc.common.ServiceInfoResponse\x12`\n\x05Unary\x12*.protocols.grpc.intention.IntentionRequest\x1a+.protocols.grpc.intention.IntentionResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protocols.grpc.intention.intention_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INTENTIONREQUEST']._serialized_start=106
  _globals['_INTENTIONREQUEST']._serialized_end=222
  _globals['_INTENTIONRESULT']._serialized_start=224
  _globals['_INTENTIONRESULT']._serialized_end=286
  _globals['_INTENTIONRESPONSE']._serialized_start=289
  _globals['_INTENTIONRESPONSE']._serialized_end=419
  _globals['_INTENTIONSERVICE']._serialized_start=422
  _globals['_INTENTIONSERVICE']._serialized_end=643
# @@protoc_insertion_point(module_scope)
