# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protocols/grpc/compose/compose.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'protocols/grpc/compose/compose.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from llmbrick.protocols.grpc.common import common_pb2 as protocols_dot_grpc_dot_common_dot_common__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$protocols/grpc/compose/compose.proto\x12\x16protocols.grpc.compose\x1a\"protocols/grpc/common/common.proto\x1a\x1cgoogle/protobuf/struct.proto\"t\n\x08\x44ocument\x12\x0e\n\x06\x64oc_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07snippet\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xb6\x01\n\x0e\x43omposeRequest\x12\x39\n\x0finput_documents\x18\x01 \x03(\x0b\x32 .protocols.grpc.compose.Document\x12\x15\n\rtarget_format\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x12\n\nrequest_id\x18\x05 \x01(\t\x12\x17\n\x0fsource_language\x18\x06 \x01(\t\"m\n\x0f\x43omposeResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\".protocols.grpc.common.ErrorDetail2\xb9\x02\n\x0e\x43omposeService\x12g\n\x0eGetServiceInfo\x12).protocols.grpc.common.ServiceInfoRequest\x1a*.protocols.grpc.common.ServiceInfoResponse\x12X\n\x05Unary\x12&.protocols.grpc.compose.ComposeRequest\x1a\'.protocols.grpc.compose.ComposeResponse\x12\x64\n\x0fOutputStreaming\x12&.protocols.grpc.compose.ComposeRequest\x1a\'.protocols.grpc.compose.ComposeResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protocols.grpc.compose.compose_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DOCUMENT']._serialized_start=130
  _globals['_DOCUMENT']._serialized_end=246
  _globals['_COMPOSEREQUEST']._serialized_start=249
  _globals['_COMPOSEREQUEST']._serialized_end=431
  _globals['_COMPOSERESPONSE']._serialized_start=433
  _globals['_COMPOSERESPONSE']._serialized_end=542
  _globals['_COMPOSESERVICE']._serialized_start=545
  _globals['_COMPOSESERVICE']._serialized_end=858
# @@protoc_insertion_point(module_scope)
