syntax = "proto3";

package protocols.grpc.intention;


import "protocols/grpc/common/common.proto";

// Intention Brick 相關訊息
message IntentionRequest {
  string text = 1;
  string client_id = 2;
  string session_id = 3;
  string request_id = 4;
  string source_language = 5;
}

message IntentionResult {
  string intent_category = 1;   // 例: "chat", "command", "question", ...
  float confidence = 2;         // 信度 0~1
}

message IntentionResponse {
  repeated IntentionResult results = 1;
  protocols.grpc.common.ErrorDetail error = 2;
}

service IntentionService {
  rpc GetServiceInfo(protocols.grpc.common.ServiceInfoRequest) returns (protocols.grpc.common.ServiceInfoResponse);
  rpc Unary(IntentionRequest) returns (IntentionResponse);
}
