# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protocols/grpc/llm/llm.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'protocols/grpc/llm/llm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from llmbrick.protocols.grpc.common import common_pb2 as protocols_dot_grpc_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprotocols/grpc/llm/llm.proto\x12\x12protocols.grpc.llm\x1a\"protocols/grpc/common/common.proto\"(\n\x07\x43ontext\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"\xd9\x01\n\nLLMRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x0e\n\x06prompt\x18\x02 \x01(\t\x12,\n\x07\x63ontext\x18\x03 \x03(\x0b\x32\x1b.protocols.grpc.llm.Context\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\x12\x12\n\nrequest_id\x18\x06 \x01(\t\x12\x17\n\x0fsource_language\x18\x07 \x01(\t\x12\x13\n\x0btemperature\x18\x08 \x01(\x02\x12\x12\n\nmax_tokens\x18\t \x01(\x05\"p\n\x0bLLMResponse\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06tokens\x18\x02 \x03(\t\x12\x10\n\x08is_final\x18\x03 \x01(\x08\x12\x31\n\x05\x65rror\x18\x04 \x01(\x0b\x32\".protocols.grpc.common.ErrorDetail2\x95\x02\n\nLLMService\x12g\n\x0eGetServiceInfo\x12).protocols.grpc.common.ServiceInfoRequest\x1a*.protocols.grpc.common.ServiceInfoResponse\x12H\n\x05Unary\x12\x1e.protocols.grpc.llm.LLMRequest\x1a\x1f.protocols.grpc.llm.LLMResponse\x12T\n\x0fOutputStreaming\x12\x1e.protocols.grpc.llm.LLMRequest\x1a\x1f.protocols.grpc.llm.LLMResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protocols.grpc.llm.llm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CONTEXT']._serialized_start=88
  _globals['_CONTEXT']._serialized_end=128
  _globals['_LLMREQUEST']._serialized_start=131
  _globals['_LLMREQUEST']._serialized_end=348
  _globals['_LLMRESPONSE']._serialized_start=350
  _globals['_LLMRESPONSE']._serialized_end=462
  _globals['_LLMSERVICE']._serialized_start=465
  _globals['_LLMSERVICE']._serialized_end=742
# @@protoc_insertion_point(module_scope)
